@@ -47,7 +47,7 @@ sub also_sealed :Sealed (label $a, Int $b, Str $c="HOLA", Int $d//=3, Int $e||=4
             $inner->foo($b->bar($inner->bar, $inner, $bench->new));
             $a = $inner;
             $a->foo;
-            $a->bar; # error!
+            $a->bar;
           };
     }
     $a->bar();
@@ -96,25 +96,24 @@ cmpthese 1_000_000, {
 
 ok(1);
 
-eval {also_sealed($x,-1)->($x)}; # x is a Foo-typed lexical, and a Foo-blessed obj
-warn $@;
-ok (length($@) > 0);
-
-$x = bless {}; #  x is still Foo-typed lexical but its value is a main-blessed obj now
-eval {also_sealed($x)->($x)};
-warn $@;
-ok (length($@) > 0);
-
-eval {also_sealed($x,"foo")->($x)};
-warn $@;
-ok (length($@) > 0);
-
 {
   package Bar;
   BEGIN {our @ISA=qw/main/}
   sub bar { 3 } # top-level of class hierarchy
   my $z = bless {};
-  eval {$z->also_sealed(-1)->($z)};
+  eval {$z->also_sealed(-1)->($z)}; # virtual method lookup verboten
   warn $@;
   main::ok (length($@) > 0);
 }
+
+eval {also_sealed($x,-1)->($x)}; # x is a Foo-typed lexical, and a Foo-blessed obj
+warn $@;
+ok (length($@) > 0);
+
+eval {also_sealed(bless({}), -1)->($x)};
+warn $@;
+ok (length($@) > 0);
+
+eval {also_sealed(bless({}),"foo")->($x)};
+warn $@;
+ok (length($@) > 0);
